@@ -37,7 +37,7 @@ signals:
 public slots:
     void build();
     void demolish();
-    bool checkCollision(int object_x, int object_y, int object_w, int object_h);
+    bool checkCollision(int object_x, int object_y, int object_w, int object_h, bool alien = false);
     bool checkCollisionRev(int object_x, int object_y, int object_w, int object_h);
 
 private:
