@@ -72,6 +72,8 @@ function cmdRunning() {
     //Start the animation timers
     heartbeat.running = true;
     alienanimation.running = true;
+
+    ship.reset();
 }
 
 function cmdLifeLost() {
@@ -102,6 +104,10 @@ function cmdDead() {
     bunker2.demolish();
     bunker3.demolish();
     bunker4.demolish();
+    if (mysteryShip != null){
+        mysteryShip.destroy();
+        mysteryShip = null;
+    }
 
     board.displayMessage("GAME OVER");
 
@@ -241,6 +247,7 @@ function destroyLivesIndication() {
 }
 
 function shipHit() {
+    ship.explode();
     if (sFX == "TRUE"){
         destroyShipSound.play();
     }
@@ -475,8 +482,7 @@ function checkBulletMysteryCollision()
                 scoretext.text = "Score: " + score;
                 bullet.y = -20; //Move the bullet offscreen
 
-                mysteryShip.destroy();
-                mysteryShip = null;
+                mysteryShip.explode();
             }
         }
     }
@@ -498,9 +504,14 @@ function checkBulletAlienCollision()
                     scoretext.text = "Score: " + score;
                     bullet.y = -20; //Move the bullet offscreen
 
+                    explosion.x = aliens[i].x - (explosion.width - aliens[i].width) /2;
+                    explosion.y = aliens[i].y - (explosion.height - aliens[i].height) /2;
+
                     aliens[i].destroy();
                     aliens[i] = null;
 
+                    explosion.play();
+
                     if (alienanimation.interval > 100) { //Get faster when a alien is killed
                         alienanimation.interval -= 10;
                     }
